@@ -1,6 +1,6 @@
 from typing import AsyncIterable
 
-from aioredis import Redis, create_redis_pool
+from redis.asyncio import Connection, Redis, from_url
 
 from aiohttp_client_cache.backends import BaseCache, CacheBackend, ResponseOrKey, get_valid_kwargs
 from aiohttp_client_cache.docs import extend_init_signature, redis_template
@@ -11,10 +11,15 @@ DEFAULT_ADDRESS = 'redis://localhost'
 @extend_init_signature(CacheBackend, redis_template)
 class RedisBackend(CacheBackend):
     """Async cache backend for `Redis <https://redis.io>`_
-    (requires `aioredis <https://aioredis.readthedocs.io>`_)
+    (requires `predis-py <https://redis-py.readthedocs.io>`_)
     """
 
     def __init__(self, cache_name: str = 'aiohttp-cache', address: str = DEFAULT_ADDRESS, **kwargs):
+        """
+        Args:
+            cache_name: Used as a namespace (prefix for hash key)
+            address: Redis server URI
+        """
         super().__init__(cache_name=cache_name, **kwargs)
         self.responses = RedisCache(cache_name, 'responses', address=address, **kwargs)
         self.redirects = RedisCache(cache_name, 'redirects', address=address, **kwargs)
@@ -33,7 +38,7 @@ class RedisCache(BaseCache):
         collection_name: name of the hash map stored in redis
         connection: An existing connection object to reuse instead of creating a new one
         address: Address of Redis server
-        kwargs: Additional keyword arguments for :py:class:`redis.Redis`
+        kwargs: Additional keyword arguments for :py:class:`aioredis.Redis`
 
     Note: The hash key name on the redis server will be ``namespace:collection_name``.
     """
@@ -50,19 +55,18 @@ class RedisCache(BaseCache):
         super().__init__(**kwargs)
         self.address = address
         self._connection = connection
-        self.connection_kwargs = get_valid_kwargs(create_redis_pool, kwargs)
+        self.connection_kwargs = get_valid_kwargs(Connection.__init__, kwargs)
         self.hash_key = f'{namespace}:{collection_name}'
 
     async def get_connection(self):
         """Lazy-initialize redis connection"""
         if not self._connection:
-            self._connection = await create_redis_pool(self.address, **self.connection_kwargs)
+            self._connection = await from_url(self.address, **self.connection_kwargs)
         return self._connection
 
     async def close(self):
         if self._connection:
-            self._connection.close()
-            await self._connection.wait_closed()
+            await self._connection.close()
             self._connection = None
 
     async def clear(self):
