@@ -42,7 +42,6 @@ extensions = [
 intersphinx_mapping = {
     'aioboto3': ('https://aioboto3.readthedocs.io/en/latest/', None),
     'aiohttp': ('https://docs.aiohttp.org/en/stable/', None),
-    'aioredis': ('https://aioredis.readthedocs.io/en/stable/', None),
     'aiosqlite': ('https://aiosqlite.omnilib.dev/en/latest/', None),
     'botocore': ('http://botocore.readthedocs.io/en/latest/', None),
     'motor': ('https://motor.readthedocs.io/en/stable/', None),
@@ -83,6 +82,7 @@ copybutton_prompt_is_regexp = True
 
 # Move type hint info to function description instead of signature
 autodoc_typehints = 'description'
+always_document_param_types = True
 set_type_checking_flag = False
 
 # Use apidoc to auto-generate rst sources
